# standard moisture calculations for air at sea level
import math

def TtoSVP(t): # input air temp:
	#returns saturated water vapour pressure in pa
    return (math.exp(t/(t + 238.3) * 17.2694) * 610.78 )

def RHandTtoVP (rh, t):
    # input rh as fraction and t C, returns vp in pa 
    return ( rh * TtoSVP( t ) )
       
def VPtoKgM3(vp, t ):
	# input vapour pressure in pa and temperature C
	#returns Kg water per cu.m. 
	return ( vp * .002167 / (t + 273.2) ) 

def KgM3toVP(kgm3, t ):
	# input Kg water per cu.m. air and temperature C
	# returns VP in pa  
	return( kgm3 * (t + 273.2) * 461.467 )

def VPtoRH(vp, t ):
	# vapour pressure, pa and temperature C
	# returns RH as fraction
	return ( vp / TtoSVP( t ) )

def VPtoKGKG(vp):
    # approx vapour pressure to kg water/kg air at ground level 
    kgprkg=0.622*vp/(101300-vp);
    return kgprkg;

def KGKGtoVP(kgkg):
    # vapour pressure in Pa from kg water/kg air at ground level
    vp = 101300 * kgkg /(kgkg + 0.622);
    return vp

