# calculates moisture diffusion from outside, into a room
#  then into its wall. Outer side of wall is impermeable.
# File vapap.py
# requires python interpreter (www.python.org)
#
# command line example:
# >python vapap.py parametersfile.txt
#
#    vapap.py is this script
#    the parameters file must not contain empty rows
#    it may contain comment lines starting with #
#    the file name must not contain spaces
#    the file path should have forward slashes: path/to/file/name
#    this works from windows98 and later
# Output format:
# output file name is [parametersfile].out.txt
#
# programmer: Tim Padfield<tim@padfield.dk>
# this program is open source, under GPLv2 licence. 
# It may freely be copied and altered
# but please describe your alterations in this comment section.
# layout of parameters file is in a separate file: params.txt


import sys, os, re, math

#IMPORT MOISTDIFF RELATED MODULES

#import Cmath, Slices, Diffusion
from Slices import * 
import Cmath


# OPEN PARAMETERS (INPUT) FILE

inputSuccess = 0

if len(sys.argv) > 1:
  try:
    startparamsfile = sys.argv[1]
    pfile = open(startparamsfile, 'r')
    inputSuccess = 1
  except:
    print 'Something wrong, try again'

if inputSuccess == 0:
  print 'needs parameters file'
  success = 0
  while success == 0:
     try:
       print 'enter path and filename:',
       startparamsfile = raw_input()
       pfile = open(startparamsfile, 'r')
       success = 1
     except:
       print 'Something wrong, try again'

# OPEN OUTPUT FILE

inFileName = startparamsfile.split('/')
inFileName = inFileName[-1]
inFileName = inFileName.split('.')
inFileName = inFileName[0]
outFileName = inFileName + '.out.txt'
ofile = open(outFileName,'w')
print ' '
print 'OUTPUT FILE ', outFileName #testing
print ' '
print 'STARTING CONDITIONS:'
print ' '

# READ STARTING PARAMETERS FROM FILE

ss = [] #make empty list of slice objects
sNumber = 0 #slice number (not type)

for line in pfile:
   pr = line.split(';')
   if pr[0] == '#': continue
   #change items 2 to last into floating point
   try:
      for a in range(2,len(pr)):
         if pr[a] == '':
            pr[a] = 0.0
         pr[a] = float(pr[a])
   except: pass
   if pr[0] == '0': # weather
      # construct Weather object
      s0 = Weather(sNumber,pr[2],pr[3],pr[4],pr[5],pr[6],pr[7],pr[8])
      ss.append(s0)
      sNumber += 1
      s0.showStatus()

   if pr[0] == '1': # room
      #construct Room object
      s1 = Room(sNumber,pr[2],pr[3],pr[4],pr[5],pr[6],pr[7],pr[8],pr[9],pr[10],pr[11])
      ss.append(s1)
      sNumber +=1
      s1.showStatus()

   if pr[0] == '3': # wall slice
      s1 = Wall(sNumber,pr[2],pr[3],pr[4],pr[5],pr[6],pr[7])
      ss.append(s1)
      ss[sNumber].showStatus()
      sNumber += 1

#READ IN GLOBAL VARIABLES

   if pr[0] == '9': # global variables list
      repRate = pr[2] #calculate every x seconds
      stopAt = pr[3] #stop at hour
      linesPerHour = pr[4] #output lines per hour
      tIncrement = repRate/3600 # calc. cycle in hours
      writeToFile = linesPerHour/tIncrement # when to write output
      if writeToFile < 1: writeToFile = 1 #but not between calc. cycles!
      print 'GLOBALS: ', 'repeat rate=',repRate,' stop at hour=',stopAt,
      print ' lines per hour=',linesPerHour
      print ' ' 


# ALL START DATA IN PLACE - SET TIME AND WEATHER

elapsedTime = 0 # hours from start of run
writeToFileCounter = 10000000 # forces results to print at time zero
numberOfSlices = len(ss)
lastSlice = numberOfSlices-1
ss[0].update(stopAt,elapsedTime) #make weather, first arg is dummy
print 'number of slices = ', numberOfSlices

# BEGIN CYCLING

while elapsedTime < stopAt :
  for s in range(1,numberOfSlices):
    ss[s].diffuse(elapsedTime,repRate,ss[s-1]) #diffuse calls update for previous slice
  ss[lastSlice].update(0.0,repRate) # update last slice with no flow to next slice

  # is it time to write to file?
  elapsedTime += tIncrement
  writeToFileCounter += 1
  if writeToFileCounter > writeToFile:
    writeToFileCounter = 0
    #compose output and print to file and to screen
    oLine = str('%3d' % elapsedTime)
    for s in range (0,numberOfSlices):
      oLine += str(' % 3.1f' % (ss[s].rh*100))
    waterContent = 0
    for s in range(3,numberOfSlices):
      waterContent += ss[s].water
    oLine += str(' %3.4f' % (waterContent))
    ofile.write(oLine)
    ofile.write('\n')
    #send diagnostics to screen
 #   for s in range(0,numberOfSlices):
  #    ss[s].showChanges()
    print oLine    

ofile.close()
pfile.close()
sys.exit(1)

